@@ -1,7 +1,7 @@
 package Bencher::Scenario::ListMoreUtils;
 
-our $DATE = '2016-01-05'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2016-06-26'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -90,11 +90,11 @@ __END__
 
 =head1 NAME
 
-Bencher::Scenario::ListMoreUtils
+Bencher::Scenario::ListMoreUtils - Benchmark List::MoreUtils::PP vs List::MoreUtils::XS
 
 =head1 VERSION
 
-This document describes version 0.02 of Bencher::Scenario::ListMoreUtils (from Perl distribution Bencher-Scenario-ListMoreUtils), released on 2016-01-05.
+This document describes version 0.03 of Bencher::Scenario::ListMoreUtils (from Perl distribution Bencher-Scenario-ListMoreUtils), released on 2016-06-26.
 
 =head1 SYNOPSIS
 
@@ -110,6 +110,8 @@ For more options (dump scenario, list/include/exclude/add participants, list/inc
 
 =head1 BENCHMARKED MODULES
 
+Version numbers shown below are the versions used when running the sample benchmark.
+
 L<List::MoreUtils::PP> 0.413
 
 L<List::MoreUtils::XS> 0.413
@@ -118,7 +120,7 @@ L<List::MoreUtils::XS> 0.413
 
 =over
 
-=item * List::MoreUtils::PP::uniq (perl_code)
+=item * List::MoreUtils::PP::uniq (perl_code) [arg1]
 
 Function call template:
 
@@ -126,7 +128,7 @@ Function call template:
 
 
 
-=item * List::MoreUtils::XS::uniq (perl_code)
+=item * List::MoreUtils::XS::uniq (perl_code) [arg1]
 
 Code template:
 
@@ -134,7 +136,7 @@ Code template:
 
 
 
-=item * List::MoreUtils::PP::minmax (perl_code)
+=item * List::MoreUtils::PP::minmax (perl_code) [arg1]
 
 Function call template:
 
@@ -142,7 +144,7 @@ Function call template:
 
 
 
-=item * List::MoreUtils::XS::minmax (perl_code)
+=item * List::MoreUtils::XS::minmax (perl_code) [arg1]
 
 Code template:
 
@@ -150,7 +152,7 @@ Code template:
 
 
 
-=item * List::MoreUtils::PP::firstidx (perl_code)
+=item * List::MoreUtils::PP::firstidx (perl_code) [arg1]
 
 Code template:
 
@@ -158,7 +160,7 @@ Code template:
 
 
 
-=item * List::MoreUtils::XS::firstidx (perl_code)
+=item * List::MoreUtils::XS::firstidx (perl_code) [arg1]
 
 Code template:
 
@@ -166,47 +168,59 @@ Code template:
 
 
 
+=back
+
+=head1 BENCHMARK DATASETS
+
+=over
+
+=item * num10
+
+=item * num100
+
+=item * num1000
+
 =back
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.22.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
+Run on: perl: I<< v5.22.2 >>, CPU: I<< Intel(R) Core(TM) i7-4770 CPU @ 3.40GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
-Benchmark with default option:
+Benchmark with default options (C<< bencher -m ListMoreUtils >>):
 
- +-----+-------------------------------------------------------------------+------------+-----------+---------+---------+
- | seq | name                                                              | rate       | time      | errors  | samples |
- +-----+-------------------------------------------------------------------+------------+-----------+---------+---------+
- | 14  | {dataset=>"num1000",participant=>"List::MoreUtils::PP::firstidx"} | 2.46e+03   | 406μs     | 2.1e-07 | 20      |
- | 2   | {dataset=>"num1000",participant=>"List::MoreUtils::PP::uniq"}     | 3175.006   | 314.96μs  | 4.5e-11 | 27      |
- | 8   | {dataset=>"num1000",participant=>"List::MoreUtils::PP::minmax"}   | 4.02e+03   | 248μs     | 4.8e-07 | 20      |
- | 5   | {dataset=>"num1000",participant=>"List::MoreUtils::XS::uniq"}     | 4.04e+03   | 247μs     | 2.1e-07 | 20      |
- | 17  | {dataset=>"num1000",participant=>"List::MoreUtils::XS::firstidx"} | 2.022e+04  | 49.45μs   | 1.3e-08 | 20      |
- | 13  | {dataset=>"num100",participant=>"List::MoreUtils::PP::firstidx"}  | 23723.16   | 42.1529μs | 1.2e-11 | 20      |
- | 11  | {dataset=>"num1000",participant=>"List::MoreUtils::XS::minmax"}   | 2.8e+04    | 36μs      | 1.7e-07 | 20      |
- | 1   | {dataset=>"num100",participant=>"List::MoreUtils::PP::uniq"}      | 38128.4    | 26.2272μs | 1e-11   | 23      |
- | 7   | {dataset=>"num100",participant=>"List::MoreUtils::PP::minmax"}    | 38612      | 25.8987μs | 4.6e-11 | 20      |
- | 4   | {dataset=>"num100",participant=>"List::MoreUtils::XS::uniq"}      | 5.86e+04   | 17.1μs    | 2.7e-08 | 20      |
- | 16  | {dataset=>"num100",participant=>"List::MoreUtils::XS::firstidx"}  | 1.921e+05  | 5.205μs   | 1.6e-09 | 22      |
- | 12  | {dataset=>"num10",participant=>"List::MoreUtils::PP::firstidx"}   | 2e+05      | 5.1μs     | 2e-08   | 20      |
- | 0   | {dataset=>"num10",participant=>"List::MoreUtils::PP::uniq"}       | 2.7e+05    | 3.7μs     | 1.4e-09 | 28      |
- | 10  | {dataset=>"num100",participant=>"List::MoreUtils::XS::minmax"}    | 276010     | 3.62306μs | 1.1e-11 | 20      |
- | 6   | {dataset=>"num10",participant=>"List::MoreUtils::PP::minmax"}     | 3.0486e+05 | 3.2802μs  | 1.1e-11 | 20      |
- | 3   | {dataset=>"num10",participant=>"List::MoreUtils::XS::uniq"}       | 5.3356e+05 | 1.8742μs  | 1.1e-11 | 20      |
- | 15  | {dataset=>"num10",participant=>"List::MoreUtils::XS::firstidx"}   | 1.1e+06    | 0.907μs   | 4.1e-10 | 21      |
- | 9   | {dataset=>"num10",participant=>"List::MoreUtils::XS::minmax"}     | 1.66e+06   | 0.604μs   | 1e-09   | 20      |
- +-----+-------------------------------------------------------------------+------------+-----------+---------+---------+
+ +-------------------------------+---------+-----------+-----------+------------+---------+---------+
+ | participant                   | dataset | rate (/s) | time (μs) | vs_slowest |  errors | samples |
+ +-------------------------------+---------+-----------+-----------+------------+---------+---------+
+ | List::MoreUtils::PP::firstidx | num1000 |      3400 | 294       |     1      | 2.1e-07 |      20 |
+ | List::MoreUtils::PP::uniq     | num1000 |      4300 | 233       |     1.26   | 5.3e-08 |      20 |
+ | List::MoreUtils::XS::uniq     | num1000 |      5500 | 180       |     1.6    |   2e-07 |      23 |
+ | List::MoreUtils::PP::minmax   | num1000 |      7200 | 140       |     2.1    | 2.1e-07 |      20 |
+ | List::MoreUtils::XS::firstidx | num1000 |     28000 |  35       |     8.3    |   4e-08 |      20 |
+ | List::MoreUtils::PP::firstidx | num100  |     34400 |  29.1     |    10.1    | 1.1e-08 |      28 |
+ | List::MoreUtils::XS::minmax   | num1000 |     42900 |  23.3     |    12.6    | 6.7e-09 |      20 |
+ | List::MoreUtils::PP::uniq     | num100  |     52900 |  18.9     |    15.6    | 6.7e-09 |      20 |
+ | List::MoreUtils::PP::minmax   | num100  |     67000 |  14.9     |    19.7    | 6.7e-09 |      20 |
+ | List::MoreUtils::XS::uniq     | num100  |     83000 |  12       |    24      | 1.7e-08 |      20 |
+ | List::MoreUtils::XS::firstidx | num100  |    268000 |   3.73    |    78.8    | 1.6e-09 |      23 |
+ | List::MoreUtils::PP::firstidx | num10   |    299499 |   3.33891 |    88.0025 |   0     |      20 |
+ | List::MoreUtils::PP::uniq     | num10   |    392000 |   2.55    |   115      | 8.3e-10 |      20 |
+ | List::MoreUtils::XS::minmax   | num100  |    409000 |   2.44    |   120      | 8.5e-10 |      20 |
+ | List::MoreUtils::PP::minmax   | num10   |    500200 |   1.999   |   147      | 7.7e-11 |      20 |
+ | List::MoreUtils::XS::uniq     | num10   |    744500 |   1.343   |   218.8    | 4.8e-11 |      24 |
+ | List::MoreUtils::XS::firstidx | num10   |   1600000 |   0.62    |   480      | 3.3e-09 |      20 |
+ | List::MoreUtils::XS::minmax   | num10   |   2512000 |   0.3981  |   738      | 9.4e-12 |      20 |
+ +-------------------------------+---------+-----------+-----------+------------+---------+---------+
 
 
-Benchmark module startup overhead:
+Benchmark module startup overhead (C<< bencher -m ListMoreUtils --module-startup >>):
 
- +-----+---------------------+--------+-------------------+---------+---------+
- | seq | name                | time   | mod_overhead_time | errors  | samples |
- +-----+---------------------+--------+-------------------+---------+---------+
- | 2   | List::MoreUtils::XS | 12.6ms | 7.85ms            | 3.2e-05 | 20      |
- | 1   | List::MoreUtils::PP | 11ms   | 6ms               | 0.00019 | 20      |
- | 0   | perl -e1 (baseline) | 4.7ms  | 0ms               | 5.7e-05 | 22      |
- +-----+---------------------+--------+-------------------+---------+---------+
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | participant         | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
+ +---------------------+-----------+------------------------+------------+---------+---------+
+ | List::MoreUtils::XS |       8.1 |                    5.6 |        1   |   2e-05 |      20 |
+ | List::MoreUtils::PP |       6   |                    3.5 |        1   | 6.9e-05 |      20 |
+ | perl -e1 (baseline) |       2.5 |                    0   |        3.3 | 5.1e-06 |      20 |
+ +---------------------+-----------+------------------------+------------+---------+---------+
 
 =head1 DESCRIPTION
 
